@@ -2,6 +2,7 @@ import firecloud.api as fapi
 from google.cloud import storage
 from google.cloud import bigquery
 
+
 class ClientRepository:
     base_project = None
 
@@ -17,14 +18,14 @@ class ClientRepository:
 
     def __getattr__(self, ref):
         if not self._refs[ref]:
-            self._refs[ref] = self._ref_inits[ref](project = self.base_project)
+            self._refs[ref] = self._ref_inits[ref](project=self.base_project)
         return self._refs[ref]
-    
+
     def get_fapi_token(self):
         try:
             sesh = self.fapi.__getattribute__("__SESSION")
-        except AttributeError as ae:
+        except AttributeError:
             self.fapi._set_session()
         if not sesh or not sesh.credentials.valid:
             self.fapi._set_session()
-        return self.fapi.__getattribute__("__SESSION").credentials.token
\ No newline at end of file
+        return self.fapi.__getattribute__("__SESSION").credentials.token
